@@ -5,12 +5,12 @@ test_that("Accessors return the right thing", {
 
     ## simulate basic epicurve
     dat <- c(0, 2, 2, 3, 3, 5, 5, 5, 6, 6, 6, 6)
-    i <- incidence(dat)
+    i <- incidence::incidence(dat)
 
     ## example with a function for SI
-    si <- distcrete("gamma", interval = 1L,
-                    shape = 1.5,
-                    scale = 2, w = 0)
+    si <- distcrete::distcrete("gamma", interval = 1L,
+                               shape = 1.5,
+                               scale = 2, w = 0)
 
 
     pred_1 <- project(i, runif(100, 0.8, 1.9), si, n_days = 30)
